@@ -32,9 +32,14 @@ from django.core.files import File
 import json
 import random
 import string
-import re, io
+import re, io,os,errno
 # import cStringIO as StringIO
 from io import StringIO
+import base64
+from PIL import Image
+from PIL import ImageFile
+ImageFile.LOAD_TRUNCATED_IMAGES = True
+
 
 
 def randomString(stringLength=10):
@@ -301,7 +306,15 @@ def definir_documento(request,folio_pedido):
 
 @login_required(login_url='/login/')
 def index(request, template_name='djmicrosip_clasificadores/index.html'):
-	#
+	directorio=settings.MEDIA_ROOT+'\\imagenes_articulos\\'
+
+	try:
+		os.mkdir(directorio)
+	except OSError:
+		print("La creación del directorio %s falló" % directorio)
+	else:
+		print("Se ha creado el directorio: %s " % directorio)
+		
 	using = router.db_for_write(Articulo)
 	c = connections[using].cursor()
 	clasificadores = None
@@ -345,7 +358,9 @@ def index(request, template_name='djmicrosip_clasificadores/index.html'):
 	cliente_d=first_or_none(ClienteDireccion.objects.filter(rfc_curp=request.user.username))
 	if cliente_d:
 		cliente_id=cliente_d.cliente.id
-		print("************************")
+	print("*********cliente*********")	
+	print(cliente_d)	
+	print(cliente_id)	
 
 	form=ArticuloAnexosForm(request.POST or None)
 	if 'folio_pedido' in request.session:
@@ -354,8 +369,6 @@ def index(request, template_name='djmicrosip_clasificadores/index.html'):
 	if venta:
 		cliente=first_or_none(Cliente.objects.filter(id=cliente_id))
 		carrito=CarritoTemporal.objects.get_or_create(cliente=cliente)
-		print("***********")
-		print(carrito)
 		detalle_venta=None
 		if carrito:
 			carrito=carrito[0]
@@ -446,8 +459,8 @@ def index(request, template_name='djmicrosip_clasificadores/index.html'):
 				libres=None
 			else:
 				libres=LibresArticulos.objects.filter(no_serie__icontains=busqueda).values_list("articulo_id")
-			print("***************************************")
-			print(libres)
+			# print("***************************************")
+			# print(libres)
 			if libres:
 				libres_list=[valor[0] for valor in libres]
 
@@ -471,8 +484,8 @@ def index(request, template_name='djmicrosip_clasificadores/index.html'):
 				libres=None
 			else:
 				libres=LibresArticulos.objects.filter(no_serie__icontains=busqueda).values_list("articulo_id")
-			print("***************************************")
-			print(libres)
+			# print("***************************************")
+			# print(libres)
 			if libres:
 				libres_list=[valor[0] for valor in libres]
 
@@ -552,12 +565,12 @@ def index(request, template_name='djmicrosip_clasificadores/index.html'):
 			articulo.refaccion=articulos_libre.refaccion		
 			articulo.flete=articulos_libre.flete		
 
-			articulo_anex=ArticuloAnexos.objects.filter(articulo=articulo)
-			# print ("-------------------------------")
-			# print (articulo_anex)
-			if articulo_anex:
-				articulo.img=articulo_anex or None
-				articulo.pedm=articulo_anex or None
+		articulo_anex=ArticuloAnexos.objects.filter(articulo=articulo)
+		# print ("-------------------------------")
+		# print (articulo_anex)
+		if articulo_anex:
+			articulo.img=articulo_anex or None
+			articulo.pedm=articulo_anex or None
 		else:
 			for detalle in detalle_venta:
 				if detalle.articulo.id == articulo.id:
@@ -573,8 +586,8 @@ def index(request, template_name='djmicrosip_clasificadores/index.html'):
 		articulo.precio=precio_con_impuesto
 
 	
-	print("--------0000000-------")
-	print(imagenes)
+	# print("--------0000000-------")
+	# print(imagenes)
 	context={
 		'articulos':articulos,
 		'clasificadores':clasificadores,
@@ -1197,7 +1210,7 @@ def crear_usuarios_clientes(request):
 			print(rfc)
 			password = randomString(10)
 			guardar=str(password)+","+inf_cliente.email
-			user = User.objects.create_user(username = rfc, password=password,first_name=cliente.nombre,last_name='clasificadores',email=guardar)
+			user = User.objects.create_user(username = rfc, password=password,first_name=cliente.nombre,last_name='usuario_externo',email=guardar)
 			usuario_cliente=ClienteUsuario.objects.get_or_create(cliente=cliente,usuario=user.id)
 
 			using = router.db_for_write(Articulo)
@@ -1451,29 +1464,41 @@ def save_img(request):
 		articulo_id=request.GET.get('articulo_id')
 		articulo=first_or_none(Articulo.objects.filter(id=articulo_id))
 
-	if request.GET.get('img_art'):
-		img_art=request.GET.get('img_art')
-		dat_img_art=img_art.split(".")
+	# if request.GET.get('img_art'):
+	# 	img_art=request.GET.get('img_art')
+	# 	dat_img_art=img_art.split(".")
 
-	if request.GET.get('pedm_art'):
-		pedm_art=request.GET.get('pedm_art')
-		dat_pedm_art=pedm_art.split(".")
+	# if request.GET.get('pedm_art'):
+	# 	pedm_art=request.GET.get('pedm_art')
+	# 	dat_pedm_art=pedm_art.split(".")
 	
 	if request.GET.get('img_art_data'):
 		if articulo:
 			articulo_anex=ArticuloAnexos.objects.get_or_create(articulo=articulo,imagen_art=None)[0]
-			print("****************")
-			print(articulo_anex)
+			#print("****************")
+			#print(articulo_anex)
 		pedm_art_data=request.GET.get('img_art_data')
 		data_url_pattern = re.compile('data:image/(png|jpeg);base64,(.*)$')
-		signature_url = pedm_art_data
-		signature_data = data_url_pattern.match(signature_url).group(2)
-		signature_data = bytes(signature_data)
-		signature_data = decodestring(signature_data)
-		img_io = io.BytesIO(signature_data)
+		#signature_url = pedm_art_data
+		
+		if pedm_art_data is not None and len(pedm_art_data) > 0:
+
+			signature_data = data_url_pattern.match(pedm_art_data).group(2)
+			signature_data = bytes(signature_data, encoding='utf8')
+			missing_padding = len(signature_data) % 4
+			if missing_padding != 0:
+				signature_data += b'='* (4 - missing_padding)
+			
+			signature_data = base64.b64decode(signature_data)	
+			img_io = io.BytesIO(signature_data)
+			img = Image.open(img_io)
+			
 		if articulo_anex:
 			url_pedm_art=str(articulo.id)+"_"+str(articulo_anex.id)+".png"
-			articulo_anex.imagen_art.save(url_pedm_art, File(img_io))
+			img.save(settings.MEDIA_ROOT+'\\imagenes_articulos\\'+url_pedm_art)
+
+			articulo_anex.imagen_art='imagenes_articulos/'+url_pedm_art
+			articulo_anex.save()
 	
 	if request.GET.get('pedm_art_data'):
 		if articulo:
